.. webapi-error::
   :instance: djblets.webapi.errors.PERMISSION_DENIED

   Your client doesn't have permission to access this resource or to perform
   the operation. Usually this means the user your client is logged in as just
   doesn't own the resource or doesn't have the access rights needed.
